#!/usr/bin/env python

from setuptools import setup

setup(name='adjutant',
      version='0.1.1',
      author='Aku Kotkavuo',
      author_email='aku@hibana.net',
      url='http://github.com/arkx/adjutant/',
      description='A Python library for parsing StarCraft II replays.',
      py_modules=['adjutant'],
      scripts=['adjutant.py'],
      requires=['mpyq'],
      install_requires=['mpyq'],
      classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Console',
        'Intended Audience :: End Users/Desktop',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: POSIX',
        'Programming Language :: Python',
        'Topic :: Games/Entertainment :: Real Time Strategy',
        'Topic :: Software Development :: Libraries',
      ],
     )



#!/usr/bin/env python
# coding: utf-8

import os
import unittest
from adjutant import SC2Replay

TEST_DIR = os.path.realpath(os.path.dirname(__file__)) + '/'

class TestSC2Replay(unittest.TestCase):

    def setUp(self):
        self.replay = SC2Replay(TEST_DIR + 'test.SC2Replay')

    def test_init(self):
        self.assertEqual(self.replay.map, 'Toxic Slums')
        self.assertEqual(self.replay.duration, '26m 17s')
        self.assertEqual(self.replay.version, '1.0.2.16223')
        self.assertEqual(len(self.replay.players), 8)
